# mktg_uniform.py
# Written by Mark Hasegawa-Johnson, April 10, 2018
# Using lots of sample code written by Tim Mahrt
#
import os
import os.path
import sys
from praatio import tgio
from collections import deque

USAGE='''USAGE:
     python uniformTextGrid.py <transcriptions.txt> <outputdir>
     For each line in <transcriptions.txt>, create a TextGrid in <outputdir>.
     Each line of <transcriptions.txt> contains wavfile, then space-bounded phone labels:

     waveform_filename.wav seg1 seg2 seg3 ...
'''

if len(sys.argv) < 3:
    print(USAGE)
    exit(0)

transfile = sys.argv[1]
outputPath = sys.argv[2]

if not os.path.exists(outputPath):
    os.mkdir(outputPath)
    
with open(transfile) as tf:
    for line in tf:
        phones = deque(line.rstrip().split())
        if len(phones) > 0:
            wavfile = phones.popleft()
        
            name, ext = os.path.splitext(wavfile)
            if ext != ".wav":
                print("This line in {} has no wavefile: {}".format(tf,line))
            else:
                phoneTier = tgio.IntervalTier('phones', [], 0, pairedWav=wavfile)
                endTime = phoneTier.maxTimestamp
                dur = endTime/len(phones)
                for (n,ph) in enumerate(phones):
                    phoneTier.entryList.append((n*dur,min(endTime,(n+1)*dur),ph))
    
                tg = tgio.Textgrid()
                tg.addTier(phoneTier)
                tg.save(os.path.join(outputPath, name + ".TextGrid"))

